import request from '@/utils/request'


//类型


export function tKindergartenInfo(data) {
    return request({
        url: '/system/dict/data/type/' + data,
        method: 'get'
    })
}


// 查询幼儿园信息管理列表
export function listKindergartenInfo(query) {
    return request({
        url: '/system/kindergartenInfo/list',
        method: 'get',
        params: query
    })
}

// 查询幼儿园信息管理详细
export function getKindergartenInfo(id) {
    return request({
        url: '/system/kindergartenInfo/' + id,
        method: 'get'
    })
}

// 新增幼儿园信息管理
export function addKindergartenInfo(data) {
    return request({
        url: '/system/kindergartenInfo/add',
        method: 'post',
        data: data
    })
}

// 修改幼儿园信息管理
export function updateKindergartenInfo(data) {
    return request({
        url: '/system/kindergartenInfo/edit',
        method: 'post',
        data: data
    })
}

// 删除幼儿园信息管理
export function delKindergartenInfo(id) {
    return request({
        url: '/system/kindergartenInfo/' + id,
        method: 'delete'
    })
}